@@ -1,5 +1,5 @@
 package App::Wallflower;
-$App::Wallflower::VERSION = '1.013';
+$App::Wallflower::VERSION = '1.014';
 use strict;
 use warnings;
 
@@ -50,7 +50,10 @@ my @callbacks = (
                 my $i = 0;
                 $i += 2
                   while $i < @$headers && lc( $headers->[$i] ) ne 'location';
-                diag( "$url => " . ( $headers->[ $i + 1 ] || '?' ) );
+                note( "$url => " . ( $headers->[ $i + 1 ] || '?' ) );
+            }
+            elsif ( $status == 304 ) {
+              SKIP: { skip( $url, 1 ); }
             }
             else {
                 is( $status, 200, $url->path );
@@ -416,12 +419,12 @@ sub _process_queue {
 
         # obtain links to resources
         my ( $status, $headers, $file ) = @$response;
-        if ( $status eq '200' && $follow ) {
+        if ( ( $status == 200 || $status == 304 ) && $follow ) {
             $self->_push_todo( links_from( $response => $url ) );
         }
 
         # follow 301 Moved Permanently
-        elsif ( $status eq '301' ) {
+        elsif ( $status == 301 ) {
             require HTTP::Headers;
             my $l = HTTP::Headers->new(@$headers)->header('Location');
             $self->_push_todo($l) if $l;
@@ -449,7 +452,7 @@ App::Wallflower - Class performing the moves for the wallflower program
 
 =head1 VERSION
 
-version 1.013
+version 1.014
 
 =head1 SYNOPSIS
 
